@@ -57,13 +57,16 @@ def main(args=None):
         src = FileStorage(file_name=source)
         dst = NEOStorage(master_nodes=destination, name=cluster)
     else:
+        print("WARNING: due to a bug in FileStorage (at least up to ZODB trunk"
+              "@121629), output database may be corrupted if input database is"
+              " not packed.")
         src = NEOStorage(master_nodes=source, name=cluster)
         dst = FileStorage(file_name=destination)
 
     # do the job
     print "Migrating from %s to %s" % (source, destination)
     start = time.time()
-    dst.copyTransactionsFrom(src, verbose=0)
+    dst.copyTransactionsFrom(src)
     elapsed = time.time() - start
     print "Migration done in %3.5f" % (elapsed, )
 
